ParseError

Enum ParseError 

pub enum ParseError {
    InvalidChunkLayout,
    InvalidInput,
    InvalidVp8lPrefixCode,
    MissingRequiredChunk(FourCC),
    TruncatedChunk,
    UnsupportedChunk(FourCC),
    UnsupportedVp8lVersion(u8),
}
Error type returned by the WebP parser.

While the API of this error type is currently considered unstable, it is more stably guaranteed to implement Display + Debug.

Variants



InvalidChunkLayout

The input is invalid because its chunks are in a ordering or configuration disallowed by the WebP specification.



InvalidInput

The input is invalid.



InvalidVp8lPrefixCode

The VP8L image data contained an invalid prefix code.



MissingRequiredChunk(FourCC)

The input is invalid because it is missing a chunk required by the WebP specification.



TruncatedChunk

The input is invalid because the input ended before the end of a valid RIFF chunk.

This can occur either when the entire input is truncated or when a chunk size is incorrect.



UnsupportedChunk(FourCC)

The input is unsupported because it contains an unknown chunk type.



UnsupportedVp8lVersion(u8)

The input is unsupported because it contains an unknown VP8L stream version.